==> qt6-translations_6.9.2.orig.tar.xz: qttranslations-everywhere-src-6.9.2/translations/qt_help_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter</source>
        <translation>Lägg till filter</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Filternamn:</translation>
    </message>
</context>
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Namnlös</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &quot;%1&quot; is not set up yet.</source>
        <translation>Samlingsfilen &quot;%1&quot; är inte uppsatt ännu.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver.</source>
        <translation>Kan inte läsa in sqlite-databasdrivrutinen.</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Kan inte öppna samlingsfilen: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1.</source>
        <translation>Kan inte skapa tabeller i filen %1.</translation>
    </message>
    <message>
        <source>Cannot create index tables in file %1.</source>
        <translation>Kan inte skapa indextabeller i filen %1.</translation>
    </message>
    <message>
        <source>Cannot register index tables in file %1.</source>
        <translation>Kan inte registrera indextabeller i filen %1.</translation>
    </message>
    <message>
        <source>Cannot unregister index tables in file %1.</source>
        <translation>Kan inte avregistrera indextabeller i filen %1.</translation>
    </message>
    <message>
        <source>The collection file &quot;%1&quot; already exists.</source>
        <translation>Samlingsfilen &quot;%1&quot; finns redan.</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Kan inte skapa katalogen: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Kan inte kopiera samlingsfilen: %1</translation>
    </message>
    <message>
        <source>Unknown filter &quot;%1&quot;.</source>
        <translation>Okänt filter &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Cannot register filter %1.</source>
        <translation>Kan inte registrera filtret %1.</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1.</source>
        <translation>Kan inte öppna dokumentationsfilen %1.</translation>
    </message>
    <message>
        <source>Invalid documentation file &quot;%1&quot;.</source>
        <translation>Ogiltig dokumentationsfil &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered.</source>
        <translation>Namnrymden %1 var inte registrerad.</translation>
    </message>
    <message>
        <source>Namespace %1 already exists.</source>
        <translation>Namnrymden %1 finns redan.</translation>
    </message>
    <message>
        <source>Cannot register namespace &quot;%1&quot;.</source>
        <translation>Kan inte registrera namnrymden &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Cannot register virtual folder &apos;%1&apos;.</source>
        <translation>Kan inte registrera virtuella mappen &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &quot;%1&quot; &quot;%2&quot;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>Kan inte öppna databasen &quot;%1&quot; &quot;%2&quot;: %3</translation>
    </message>
</context>
<context>
    <name>QHelpFilterSettingsWidget</name>
    <message>
        <source>Form</source>
        <translation>Formulär</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Components</source>
        <translation>Komponenter</translation>
    </message>
    <message>
        <source>Versions</source>
        <translation>Versioner</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Lägg till...</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Byt namn...</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Add Filter</source>
        <translation>Lägg till filter</translation>
    </message>
    <message>
        <source>New Filter</source>
        <translation>Nytt filter</translation>
    </message>
    <message>
        <source>Rename Filter</source>
        <translation>Byt namn på filter</translation>
    </message>
    <message>
        <source>Remove Filter</source>
        <translation>Ta bort filter</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the &quot;%1&quot; filter?</source>
        <translation>Är du säker på att du vill ta bort filtret &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Filter Exists</source>
        <translation>Filtret finns redan</translation>
    </message>
    <message>
        <source>The filter &quot;%1&quot; already exists.</source>
        <translation>Filtret &quot;%1&quot; finns redan.</translation>
    </message>
    <message>
        <source>No Component</source>
        <translation>Ingen komponent</translation>
    </message>
    <message>
        <source>Invalid Component</source>
        <translation>Ogiltig komponent</translation>
    </message>
    <message>
        <source>No Version</source>
        <translation>Ingen version</translation>
    </message>
    <message>
        <source>Invalid Version</source>
        <translation>Ogiltig version</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Föregående sökning</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Nästa sökning</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 - %2 av %n träff</numerusform>
            <numerusform>%1 - %2 av %n träffar</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 - 0 av 0 träffar</translation>
    </message>
</context>
<context>
    <name>QOptionsWidget</name>
    <message>
        <source>No Option</source>
        <translation>Inget alternativ</translation>
    </message>
    <message>
        <source>Invalid Option</source>
        <translation>Ogiltigt alternativ</translation>
    </message>
</context>
<context>
    <name>QResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Sökresultat</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Anteckning:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed.</source>
        <translation>Sökresultaten kanske inte är kompletta eftersom dokumentationen fortfarande indexeras.</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Din sökning matchade inte några dokument.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Anledningen för detta kanske är att dokumentationen fortfarande indexeras.)</translation>
    </message>
</context>
<context>
    <name>fulltextsearch::qt::QHelpSearchIndexWriter</name>
    <message>
        <source>Cannot open database &quot;%1&quot; using connection &quot;%2&quot;: %3</source>
        <translation>Kan inte öppna databasen &quot;%1&quot; med anslutningen &quot;%2&quot;: %3</translation>
    </message>
</context>
</TS>

==> qt6-translations_6.10.2.orig.tar.xz: qttranslations-everywhere-src-6.10.2/translations/qt_help_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter</source>
        <translation>Lägg till filter</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Filternamn:</translation>
    </message>
</context>
<context>
    <name>QHelpFilterSettingsWidget</name>
    <message>
        <source>Form</source>
        <translation>Formulär</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Components</source>
        <translation>Komponenter</translation>
    </message>
    <message>
        <source>Versions</source>
        <translation>Versioner</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Lägg till...</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Byt namn...</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Add Filter</source>
        <translation>Lägg till filter</translation>
    </message>
    <message>
        <source>New Filter</source>
        <translation>Nytt filter</translation>
    </message>
    <message>
        <source>Rename Filter</source>
        <translation>Byt namn på filter</translation>
    </message>
    <message>
        <source>Remove Filter</source>
        <translation>Ta bort filter</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the &quot;%1&quot; filter?</source>
        <translation>Är du säker på att du vill ta bort filtret &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Filter Exists</source>
        <translation>Filtret finns redan</translation>
    </message>
    <message>
        <source>The filter &quot;%1&quot; already exists.</source>
        <translation>Filtret &quot;%1&quot; finns redan.</translation>
    </message>
    <message>
        <source>No Component</source>
        <translation>Ingen komponent</translation>
    </message>
    <message>
        <source>Invalid Component</source>
        <translation>Ogiltig komponent</translation>
    </message>
    <message>
        <source>No Version</source>
        <translation>Ingen version</translation>
    </message>
    <message>
        <source>Invalid Version</source>
        <translation>Ogiltig version</translation>
    </message>
</context>
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Namnlös</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &quot;%1&quot; is not set up yet.</source>
        <translation>Samlingsfilen &quot;%1&quot; är inte uppsatt ännu.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver.</source>
        <translation>Kan inte läsa in sqlite-databasdrivrutinen.</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Kan inte öppna samlingsfilen: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1.</source>
        <translation>Kan inte skapa tabeller i filen %1.</translation>
    </message>
    <message>
        <source>Cannot create index tables in file %1.</source>
        <translation>Kan inte skapa indextabeller i filen %1.</translation>
    </message>
    <message>
        <source>Cannot register index tables in file %1.</source>
        <translation>Kan inte registrera indextabeller i filen %1.</translation>
    </message>
    <message>
        <source>Cannot unregister index tables in file %1.</source>
        <translation>Kan inte avregistrera indextabeller i filen %1.</translation>
    </message>
    <message>
        <source>The collection file &quot;%1&quot; already exists.</source>
        <translation>Samlingsfilen &quot;%1&quot; finns redan.</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Kan inte skapa katalogen: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Kan inte kopiera samlingsfilen: %1</translation>
    </message>
    <message>
        <source>Unknown filter &quot;%1&quot;.</source>
        <translation>Okänt filter &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Cannot register filter %1.</source>
        <translation>Kan inte registrera filtret %1.</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1.</source>
        <translation>Kan inte öppna dokumentationsfilen %1.</translation>
    </message>
    <message>
        <source>Invalid documentation file &quot;%1&quot;.</source>
        <translation>Ogiltig dokumentationsfil &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered.</source>
        <translation>Namnrymden %1 var inte registrerad.</translation>
    </message>
    <message>
        <source>Namespace %1 already exists.</source>
        <translation>Namnrymden %1 finns redan.</translation>
    </message>
    <message>
        <source>Cannot register namespace &quot;%1&quot;.</source>
        <translation>Kan inte registrera namnrymden &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Cannot register virtual folder &apos;%1&apos;.</source>
        <translation>Kan inte registrera virtuella mappen &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &quot;%1&quot; &quot;%2&quot;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>Kan inte öppna databasen &quot;%1&quot; &quot;%2&quot;: %3</translation>
    </message>
</context>
<context>
    <name>fulltextsearch::QHelpSearchIndexWriter</name>
    <message>
        <source>Cannot open database &quot;%1&quot; using connection &quot;%2&quot;: %3</source>
        <translation>Kan inte öppna databasen &quot;%1&quot; med anslutningen &quot;%2&quot;: %3</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Föregående sökning</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Nästa sökning</translation>
    </message>
</context>
<context>
    <name>QResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Sökresultat</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Anteckning:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed.</source>
        <translation>Sökresultaten kanske inte är kompletta eftersom dokumentationen fortfarande indexeras.</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Din sökning matchade inte några dokument.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Anledningen för detta kanske är att dokumentationen fortfarande indexeras.)</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 - %2 av %n träff</numerusform>
            <numerusform>%1 - %2 av %n träffar</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 - 0 av 0 träffar</translation>
    </message>
</context>
<context>
    <name>QOptionsWidget</name>
    <message>
        <source>No Option</source>
        <translation>Inget alternativ</translation>
    </message>
    <message>
        <source>Invalid Option</source>
        <translation>Ogiltigt alternativ</translation>
    </message>
</context>
</TS>
